#ifndef UTILITIES_IO_
#define UTILITIES_IO_

#include <stdio.h>

namespace Utilities
{
	namespace IO
	{
		extern FILE * stream;
	}
}

#endif
